# fateslist.py

Work in progress library for Fates List

## Issues And Contributing

This API wrapper/library is maintained by ``Rootspring#6701``. If you wish to contribute to this project or report an issue, please make a Github Issue or a Pull Request (templates coming soon)
